@@ -11,7 +11,7 @@ class RCatTypes:
         self._rcattypes.append(RCatType(params))
 
     @classmethod
-    def find_by_id(cls, id):
+    def find_by_id(cls, id) -> RCatType:
         obj = list(filter(lambda x: x.actv_code_type_id == id, cls._rcattypes))
         if len(obj) > 0:
             return obj[0]
@@ -27,7 +27,7 @@ class RCatTypes:
     def __iter__(self):
         return self
 
-    def __next__(self):
+    def __next__(self) -> RCatType:
         if self.index >= len(self._rcattypes):
             raise StopIteration
         idx = self.index
