@@ -11,7 +11,7 @@ class RoleRates:
         self._rolerates.append(RoleRate(params))
 
     @classmethod
-    def find_by_id(cls, id):
+    def find_by_id(cls, id) -> RoleRate:
         obj = list(filter(lambda x: x.actv_code_type_id == id, cls._rolerates))
         if len(obj) > 0:
             return obj[0]
@@ -27,7 +27,7 @@ class RoleRates:
     def __iter__(self):
         return self
 
-    def __next__(self):
+    def __next__(self) -> RoleRate:
         if self.index >= len(self._rolerates):
             raise StopIteration
         idx = self.index
